<?php
/**
 * 珑大极简商城
 * 
 *  ==========================================================================
 *  @link      https://shop.loongdom.cn/
 *  @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 *  @license   https://shop.loongdom.cn/license.html License
 *  ==========================================================================
 * 
 * @author    静静的风
 */


namespace Goods\Entity;

use Admin\Entity\BaseEntity as BaseEntity;
use Doctrine\ORM\Mapping as ORM;

/**
 * 商品基本表
 *
 * @ORM\Entity(repositoryClass="Goods\Repository\GoodsRepository")
 * @ORM\Table(name="loongdom_goods")
 */
class Goods extends BaseEntity
{

    /**
     * 自增id
     *
     * @ORM\Id()
     * @ORM\Column(name="goods_id", type="integer", length=11)
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $goodsId;

    /**
     * 商品编号
     *
     * @ORM\Column(name="goods_item", type="string", length=50)
     */
    private $goodsItem;

    /**
     * 商品分类id
     *
     * @ORM\Column(name="class_id", type="integer", length=11)
     */
    private $classId;

    /**
     * 商品名称
     *
     * @ORM\Column(name="goods_name", type="string", length=200)
     */
    private $goodsName;

    /**
     * 扩展商品名称
     *
     * @ORM\Column(name="goods_extend_name", type="string", length=255)
     */
    private $goodsExtendName;

    /**
     * 库存id
     *
     * @ORM\Column(name="stock_id", type="integer", length=11)
     */
    private $stockId;

    /**
     * 商品重量
     *
     * @ORM\Column(name="goods_weight", type="integer", length=11)
     */
    private $goodsWeight;

    /**
     * 重量转换值， goods_weight * goods_weight_conversion =
     * 单个商品重量（克）
     *
     * @ORM\Column(name="goods_weight_conversion", type="integer", length=11)
     */
    private $goodsWeightConversion;

    /**
     * 重量单位
     *
     * @ORM\Column(name="goods_weight_unit", type="string", length=20)
     */
    private $goodsWeightUnit;

    /**
     * 商品关键词SEO
     *
     * @ORM\Column(name="goods_keywords", type="string", length=255)
     */
    private $goodsKeywords;

    /**
     * 商品描述SEO
     *
     * @ORM\Column(name="goods_description", type="string", length=1000)
     */
    private $goodsDescription;

    /**
     * 市场价格
     *
     * @ORM\Column(name="goods_market_price", type="decimal", scale=2)
     */
    private $goodsMarketPrice;

    /**
     * 商品价格
     *
     * @ORM\Column(name="goods_price", type="decimal", scale=2)
     */
    private $goodsPrice;

    /**
     * 商品详情
     *
     * @ORM\Column(name="goods_body", type="text")
     */
    private $goodsBody;

    /**
     * 商品状态，1 上架，2 下架
     *
     * @ORM\Column(name="goods_state", type="integer", length=1)
     */
    private $goodsState;

    /**
     * 商品图片id
     *
     * @ORM\Column(name="goods_image_id", type="integer", length=11)
     */
    private $goodsImageId = 0;

    /**
     * 浏览量
     *
     * @ORM\Column(name="goods_click", type="integer", length=11)
     */
    private $goodsClick = 0;

    /**
     * 商品添加时间
     *
     * @ORM\Column(name="goods_add_time", type="integer", length=10)
     */
    private $goodsAddTime;

    /**
     * @ORM\Column(name="spec_state", type="integer", length=1)
     */
    private $specState = 0;

    /**
     * Get the value of 自增id
     *
     * @return mixed
     */
    public function getGoodsId()
    {
        return $this->goodsId;
    }

    /**
     * Set the value of 自增id
     *
     * @param mixed $goodsId
     */
    public function setGoodsId($goodsId) : void
    {
        $this->goodsId = $goodsId;
    }

    /**
     * Get the value of 商品编号
     *
     * @return mixed
     */
    public function getGoodsItem()
    {
        return $this->goodsItem;
    }

    /**
     * Set the value of 商品编号
     *
     * @param mixed $goodsItem
     */
    public function setGoodsItem($goodsItem) : void
    {
        $this->goodsItem = $goodsItem;
    }

    /**
     * Get the value of 商品分类id
     *
     * @return mixed
     */
    public function getClassId()
    {
        return $this->classId;
    }

    /**
     * Set the value of 商品分类id
     *
     * @param mixed $classId
     */
    public function setClassId($classId) : void
    {
        $this->classId = $classId;
    }

    /**
     * Get the value of 商品名称
     *
     * @return mixed
     */
    public function getGoodsName()
    {
        return $this->goodsName;
    }

    /**
     * Set the value of 商品名称
     *
     * @param mixed $goodsName
     */
    public function setGoodsName($goodsName) : void
    {
        $this->goodsName = $goodsName;
    }

    /**
     * Get the value of 扩展商品名称
     *
     * @return mixed
     */
    public function getGoodsExtendName()
    {
        return $this->goodsExtendName;
    }

    /**
     * Set the value of 扩展商品名称
     *
     * @param mixed $goodsExtendName
     */
    public function setGoodsExtendName($goodsExtendName) : void
    {
        $this->goodsExtendName = $goodsExtendName;
    }

    /**
     * Get the value of 库存id
     *
     * @return mixed
     */
    public function getStockId()
    {
        return $this->stockId;
    }

    /**
     * Set the value of 库存id
     *
     * @param mixed $stockId
     */
    public function setStockId($stockId) : void
    {
        $this->stockId = $stockId;
    }

    /**
     * Get the value of 商品重量
     *
     * @return mixed
     */
    public function getGoodsWeight()
    {
        return $this->goodsWeight;
    }

    /**
     * Set the value of 商品重量
     *
     * @param mixed $goodsWeight
     */
    public function setGoodsWeight($goodsWeight) : void
    {
        $this->goodsWeight = $goodsWeight;
    }

    /**
     * Get the value of 重量转换值， goods_weight * goods_weight_conversion =
     * 单个商品重量（克）
     *
     * @return mixed
     */
    public function getGoodsWeightConversion()
    {
        return $this->goodsWeightConversion;
    }

    /**
     * Set the value of 重量转换值， goods_weight * goods_weight_conversion =
     * 单个商品重量（克）
     *
     * @param mixed $goodsWeightConversion
     */
    public function setGoodsWeightConversion($goodsWeightConversion) : void
    {
        $this->goodsWeightConversion = $goodsWeightConversion;
    }

    /**
     * Get the value of 重量单位
     *
     * @return mixed
     */
    public function getGoodsWeightUnit()
    {
        return $this->goodsWeightUnit;
    }

    /**
     * Set the value of 重量单位
     *
     * @param mixed $goodsWeightUnit
     */
    public function setGoodsWeightUnit($goodsWeightUnit) : void
    {
        $this->goodsWeightUnit = $goodsWeightUnit;
    }

    /**
     * Get the value of 商品关键词SEO
     *
     * @return mixed
     */
    public function getGoodsKeywords()
    {
        return $this->goodsKeywords;
    }

    /**
     * Set the value of 商品关键词SEO
     *
     * @param mixed $goodsKeywords
     */
    public function setGoodsKeywords($goodsKeywords) : void
    {
        $this->goodsKeywords = $goodsKeywords;
    }

    /**
     * Get the value of 商品描述SEO
     *
     * @return mixed
     */
    public function getGoodsDescription()
    {
        return $this->goodsDescription;
    }

    /**
     * Set the value of 商品描述SEO
     *
     * @param mixed $goodsDescription
     */
    public function setGoodsDescription($goodsDescription) : void
    {
        $this->goodsDescription = $goodsDescription;
    }

    /**
     * Get the value of 市场价格
     *
     * @return mixed
     */
    public function getGoodsMarketPrice()
    {
        return $this->goodsMarketPrice;
    }

    /**
     * Set the value of 市场价格
     *
     * @param mixed $goodsMarketPrice
     */
    public function setGoodsMarketPrice($goodsMarketPrice) : void
    {
        $this->goodsMarketPrice = $goodsMarketPrice;
    }

    /**
     * Get the value of 商品价格
     *
     * @return mixed
     */
    public function getGoodsPrice()
    {
        return $this->goodsPrice;
    }

    /**
     * Set the value of 商品价格
     *
     * @param mixed $goodsPrice
     */
    public function setGoodsPrice($goodsPrice) : void
    {
        $this->goodsPrice = $goodsPrice;
    }

    /**
     * Get the value of 商品详情
     *
     * @return mixed
     */
    public function getGoodsBody()
    {
        return $this->goodsBody;
    }

    /**
     * Set the value of 商品详情
     *
     * @param mixed $goodsBody
     */
    public function setGoodsBody($goodsBody) : void
    {
        $this->goodsBody = $goodsBody;
    }

    /**
     * Get the value of 商品状态，1 上架，2 下架
     *
     * @return mixed
     */
    public function getGoodsState()
    {
        return $this->goodsState;
    }

    /**
     * Set the value of 商品状态，1 上架，2 下架
     *
     * @param mixed $goodsState
     */
    public function setGoodsState($goodsState) : void
    {
        $this->goodsState = $goodsState;
    }

    /**
     * Get the value of 商品图片id
     *
     * @return mixed
     */
    public function getGoodsImageId()
    {
        return $this->goodsImageId;
    }

    /**
     * Set the value of 商品图片id
     *
     * @param mixed $goodsImageId
     */
    public function setGoodsImageId($goodsImageId) : void
    {
        $this->goodsImageId = $goodsImageId;
    }

    /**
     * Get the value of 浏览量
     *
     * @return mixed
     */
    public function getGoodsClick()
    {
        return $this->goodsClick;
    }

    /**
     * Set the value of 浏览量
     *
     * @param mixed $goodsClick
     */
    public function setGoodsClick($goodsClick) : void
    {
        $this->goodsClick = $goodsClick;
    }

    /**
     * Get the value of 商品添加时间
     *
     * @return mixed
     */
    public function getGoodsAddTime()
    {
        return $this->goodsAddTime;
    }

    /**
     * Set the value of 商品添加时间
     *
     * @param mixed $goodsAddTime
     */
    public function setGoodsAddTime($goodsAddTime) : void
    {
        $this->goodsAddTime = $goodsAddTime;
    }

    public function getSpecState(): int
    {
        return $this->specState;
    }

    public function setSpecState(int $specState): void
    {
        $this->specState = $specState;
    }

}

