<?php
/**
 * 珑大极简商城
 * 
 *  ==========================================================================
 *  @link      https://shop.loongdom.cn/
 *  @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 *  @license   https://shop.loongdom.cn/license.html License
 *  ==========================================================================
 * 
 * @author    静静的风
 */


namespace Goods\Entity;

use Admin\Entity\BaseEntity as BaseEntity;
use Doctrine\ORM\Mapping as ORM;

/**
 * 商品库存与购买设置表
 *
 * @ORM\Entity(repositoryClass="Goods\Repository\GoodsStockRepository")
 * @ORM\Table(name="loongdom_goods_stock")
 */
class GoodsStock extends BaseEntity
{

    /**
     * 自增id
     *
     * @ORM\Id()
     * @ORM\Column(name="stock_id", type="integer", length=11)
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $stockId;

    /**
     * 商品id
     *
     * @ORM\Column(name="goods_id", type="integer", length=11)
     */
    private $goodsId;

    /**
     * 库存数量（当有规格商品时，库存以规格商品为准）
     *
     * @ORM\Column(name="stock_num", type="decimal", scale=2)
     */
    private $stockNum = 0;

    /**
     * 库存显示文字（有货时的显示）
     *
     * @ORM\Column(name="stock_show", type="string", length=30)
     */
    private $stockShow;

    /**
     * 库存显示状态， 1
     * 启用-商品库存不减少（启用后显示上面stock_show的文字），2
     * 启用-商品库存减少， 0 关闭
     *
     * @ORM\Column(name="stock_show_state", type="integer", length=1)
     */
    private $stockShowState;

    /**
     * 商品缺货数量
     *
     * @ORM\Column(name="stock_out_set_num", type="integer", length=11)
     */
    private $stockOutSetNum;

    /**
     * 库存缺货显示文字
     *
     * @ORM\Column(name="stock_out_show", type="string", length=30)
     */
    private $stockOutShow;

    /**
     * 购物车最少数量， 0 不限制
     *
     * @ORM\Column(name="cart_buy_min_num", type="integer", length=11)
     */
    private $cartBuyMinNum;

    /**
     * 购物车最多数量， 0 不限制
     *
     * @ORM\Column(name="cart_buy_max_num", type="integer", length=11)
     */
    private $cartBuyMaxNum;

    /**
     * 每人最多买的次数， 0 不限制
     *
     * @ORM\Column(name="person_buy_max", type="integer", length=11)
     */
    private $personBuyMax;

    /**
     * Get the value of 自增id
     *
     * @return mixed
     */
    public function getStockId()
    {
        return $this->stockId;
    }

    /**
     * Set the value of 自增id
     *
     * @param mixed $stockId
     */
    public function setStockId($stockId) : void
    {
        $this->stockId = $stockId;
    }

    /**
     * Get the value of 商品id
     *
     * @return mixed
     */
    public function getGoodsId()
    {
        return $this->goodsId;
    }

    /**
     * Set the value of 商品id
     *
     * @param mixed $goodsId
     */
    public function setGoodsId($goodsId) : void
    {
        $this->goodsId = $goodsId;
    }

    /**
     * Get the value of
     * 库存数量（当有规格商品时，库存以规格商品为准）
     *
     * @return mixed
     */
    public function getStockNum()
    {
        return $this->stockNum;
    }

    /**
     * Set the value of
     * 库存数量（当有规格商品时，库存以规格商品为准）
     *
     * @param mixed $stockNum
     */
    public function setStockNum($stockNum) : void
    {
        $this->stockNum = $stockNum;
    }

    /**
     * Get the value of 库存显示文字（有货时的显示）
     *
     * @return mixed
     */
    public function getStockShow()
    {
        return $this->stockShow;
    }

    /**
     * Set the value of 库存显示文字（有货时的显示）
     *
     * @param mixed $stockShow
     */
    public function setStockShow($stockShow) : void
    {
        $this->stockShow = $stockShow;
    }

    /**
     * Get the value of 库存显示状态， 1
     * 启用-商品库存不减少（启用后显示上面stock_show的文字），2
     * 启用-商品库存减少， 0 关闭
     *
     * @return mixed
     */
    public function getStockShowState()
    {
        return $this->stockShowState;
    }

    /**
     * Set the value of 库存显示状态， 1
     * 启用-商品库存不减少（启用后显示上面stock_show的文字），2
     * 启用-商品库存减少， 0 关闭
     *
     * @param mixed $stockShowState
     */
    public function setStockShowState($stockShowState) : void
    {
        $this->stockShowState = $stockShowState;
    }

    /**
     * Get the value of 商品缺货数量
     *
     * @return mixed
     */
    public function getStockOutSetNum()
    {
        return $this->stockOutSetNum;
    }

    /**
     * Set the value of 商品缺货数量
     *
     * @param mixed $stockOutSetNum
     */
    public function setStockOutSetNum($stockOutSetNum) : void
    {
        $this->stockOutSetNum = $stockOutSetNum;
    }

    /**
     * Get the value of 库存缺货显示文字
     *
     * @return mixed
     */
    public function getStockOutShow()
    {
        return $this->stockOutShow;
    }

    /**
     * Set the value of 库存缺货显示文字
     *
     * @param mixed $stockOutShow
     */
    public function setStockOutShow($stockOutShow) : void
    {
        $this->stockOutShow = $stockOutShow;
    }

    /**
     * Get the value of 购物车最少数量， 0 不限制
     *
     * @return mixed
     */
    public function getCartBuyMinNum()
    {
        return $this->cartBuyMinNum;
    }

    /**
     * Set the value of 购物车最少数量， 0 不限制
     *
     * @param mixed $cartBuyMinNum
     */
    public function setCartBuyMinNum($cartBuyMinNum) : void
    {
        $this->cartBuyMinNum = $cartBuyMinNum;
    }

    /**
     * Get the value of 购物车最多数量， 0 不限制
     *
     * @return mixed
     */
    public function getCartBuyMaxNum()
    {
        return $this->cartBuyMaxNum;
    }

    /**
     * Set the value of 购物车最多数量， 0 不限制
     *
     * @param mixed $cartBuyMaxNum
     */
    public function setCartBuyMaxNum($cartBuyMaxNum) : void
    {
        $this->cartBuyMaxNum = $cartBuyMaxNum;
    }

    /**
     * Get the value of 每人最多买的次数， 0 不限制
     *
     * @return mixed
     */
    public function getPersonBuyMax()
    {
        return $this->personBuyMax;
    }

    /**
     * Set the value of 每人最多买的次数， 0 不限制
     *
     * @param mixed $personBuyMax
     */
    public function setPersonBuyMax($personBuyMax) : void
    {
        $this->personBuyMax = $personBuyMax;
    }


}

