<?php
/**
 * 珑大极简商城
 * 
 *  ==========================================================================
 *  @link      https://shop.loongdom.cn/
 *  @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 *  @license   https://shop.loongdom.cn/license.html License
 *  ==========================================================================
 * 
 * @author    静静的风
 */


namespace Operation\Entity;

use Admin\Entity\BaseEntity as BaseEntity;
use Doctrine\ORM\Mapping as ORM;

/**
 * 优惠促销规则表
 *
 * @ORM\Entity(repositoryClass="Operation\Repository\DiscountRuleRepository")
 * @ORM\Table(name="loongdom_discount_rule")
 */
class DiscountRule extends BaseEntity
{

    /**
     * 自增id
     *
     * @ORM\Id()
     * @ORM\Column(name="discount_rule_id", type="integer", length=11)
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $discountRuleId;

    /**
     * 优惠名称
     *
     * @ORM\Column(name="discount_rule_title", type="string", length=150)
     */
    private $discountRuleTitle;

    /**
     * 优惠描述
     *
     * @ORM\Column(name="discount_rule_info", type="string", length=500)
     */
    private $discountRuleInfo;

    /**
     * 开始时间
     *
     * @ORM\Column(name="discount_start_time", type="integer", length=10)
     */
    private $discountStartTime;

    /**
     * 结束时间
     *
     * @ORM\Column(name="discount_end_time", type="integer", length=10)
     */
    private $discountEndTime;

    /**
     * 购买次数（每人）
     *
     * @ORM\Column(name="user_buy_frequency", type="integer", length=11)
     */
    private $userBuyFrequency;

    /**
     * 状态，0 禁用，1 启用
     *
     * @ORM\Column(name="discount_state", type="integer", length=1)
     */
    private $discountState;

    /**
     * 购买类型，1 满X元，2 每X元
     *
     * @ORM\Column(name="goods_buy_type", type="integer", length=1)
     */
    private $goodsBuyType;

    /**
     * 购物金额
     *
     * @ORM\Column(name="goods_buy_amount", type="integer", length=11)
     */
    private $goodsBuyAmount;

    /**
     * 优惠金额（百分比），这里的优惠是减少的金额
     *
     * @ORM\Column(name="buy_discount", type="integer", length=11)
     */
    private $buyDiscount;

    /**
     * 优惠模式，1 金额元，2 百分比
     *
     * @ORM\Column(name="discount_mode", type="integer", length=1)
     */
    private $discountMode;

    /**
     * 客户组类型，allUser 所有客户，userGroup 客户组
     *
     * @ORM\Column(name="discount_user_type", type="string", length=30)
     */
    private $discountUserType;

    /**
     * 个性化客户组内容
     *
     * @ORM\Column(name="discount_user_group", type="text")
     */
    private $discountUserGroup;

    /**
     * 商品类型，allGoods 所有商品，goodsClass 商品分类，goodsBrand
     * 商品品牌
     *
     * @ORM\Column(name="discount_goods_type", type="string", length=30)
     */
    private $discountGoodsType;

    /**
     * 商品类型的内容，如 商品分类、商品品牌、个别商品
     *
     * @ORM\Column(name="discount_goods_body", type="text")
     */
    private $discountGoodsBody;

    /**
     * Get the value of 自增id
     *
     * @return mixed
     */
    public function getDiscountRuleId()
    {
        return $this->discountRuleId;
    }

    /**
     * Set the value of 自增id
     *
     * @param mixed $discountRuleId
     */
    public function setDiscountRuleId($discountRuleId) : void
    {
        $this->discountRuleId = $discountRuleId;
    }

    /**
     * Get the value of 优惠名称
     *
     * @return mixed
     */
    public function getDiscountRuleTitle()
    {
        return $this->discountRuleTitle;
    }

    /**
     * Set the value of 优惠名称
     *
     * @param mixed $discountRuleTitle
     */
    public function setDiscountRuleTitle($discountRuleTitle) : void
    {
        $this->discountRuleTitle = $discountRuleTitle;
    }

    /**
     * Get the value of 优惠描述
     *
     * @return mixed
     */
    public function getDiscountRuleInfo()
    {
        return $this->discountRuleInfo;
    }

    /**
     * Set the value of 优惠描述
     *
     * @param mixed $discountRuleInfo
     */
    public function setDiscountRuleInfo($discountRuleInfo) : void
    {
        $this->discountRuleInfo = $discountRuleInfo;
    }

    /**
     * Get the value of 开始时间
     *
     * @return mixed
     */
    public function getDiscountStartTime()
    {
        return $this->discountStartTime;
    }

    /**
     * Set the value of 开始时间
     *
     * @param mixed $discountStartTime
     */
    public function setDiscountStartTime($discountStartTime) : void
    {
        $this->discountStartTime = $discountStartTime;
    }

    /**
     * Get the value of 结束时间
     *
     * @return mixed
     */
    public function getDiscountEndTime()
    {
        return $this->discountEndTime;
    }

    /**
     * Set the value of 结束时间
     *
     * @param mixed $discountEndTime
     */
    public function setDiscountEndTime($discountEndTime) : void
    {
        $this->discountEndTime = $discountEndTime;
    }

    /**
     * Get the value of 购买次数（每人）
     *
     * @return mixed
     */
    public function getUserBuyFrequency()
    {
        return $this->userBuyFrequency;
    }

    /**
     * Set the value of 购买次数（每人）
     *
     * @param mixed $userBuyFrequency
     */
    public function setUserBuyFrequency($userBuyFrequency) : void
    {
        $this->userBuyFrequency = $userBuyFrequency;
    }

    /**
     * Get the value of 状态，0 禁用，1 启用
     *
     * @return mixed
     */
    public function getDiscountState()
    {
        return $this->discountState;
    }

    /**
     * Set the value of 状态，0 禁用，1 启用
     *
     * @param mixed $discountState
     */
    public function setDiscountState($discountState) : void
    {
        $this->discountState = $discountState;
    }

    /**
     * Get the value of 购买类型，1 满X元，2 每X元
     *
     * @return mixed
     */
    public function getGoodsBuyType()
    {
        return $this->goodsBuyType;
    }

    /**
     * Set the value of 购买类型，1 满X元，2 每X元
     *
     * @param mixed $goodsBuyType
     */
    public function setGoodsBuyType($goodsBuyType) : void
    {
        $this->goodsBuyType = $goodsBuyType;
    }

    /**
     * Get the value of 购物金额
     *
     * @return mixed
     */
    public function getGoodsBuyAmount()
    {
        return $this->goodsBuyAmount;
    }

    /**
     * Set the value of 购物金额
     *
     * @param mixed $goodsBuyAmount
     */
    public function setGoodsBuyAmount($goodsBuyAmount) : void
    {
        $this->goodsBuyAmount = $goodsBuyAmount;
    }

    /**
     * Get the value of 优惠金额（百分比），这里的优惠是减少的金额
     *
     * @return mixed
     */
    public function getBuyDiscount()
    {
        return $this->buyDiscount;
    }

    /**
     * Set the value of 优惠金额（百分比），这里的优惠是减少的金额
     *
     * @param mixed $buyDiscount
     */
    public function setBuyDiscount($buyDiscount) : void
    {
        $this->buyDiscount = $buyDiscount;
    }

    /**
     * Get the value of 优惠模式，1 金额元，2 百分比
     *
     * @return mixed
     */
    public function getDiscountMode()
    {
        return $this->discountMode;
    }

    /**
     * Set the value of 优惠模式，1 金额元，2 百分比
     *
     * @param mixed $discountMode
     */
    public function setDiscountMode($discountMode) : void
    {
        $this->discountMode = $discountMode;
    }

    /**
     * Get the value of 客户组类型，allUser 所有客户，userGroup 客户组
     *
     * @return mixed
     */
    public function getDiscountUserType()
    {
        return $this->discountUserType;
    }

    /**
     * Set the value of 客户组类型，allUser 所有客户，userGroup 客户组
     *
     * @param mixed $discountUserType
     */
    public function setDiscountUserType($discountUserType) : void
    {
        $this->discountUserType = $discountUserType;
    }

    /**
     * Get the value of 个性化客户组内容
     *
     * @return mixed
     */
    public function getDiscountUserGroup()
    {
        return $this->discountUserGroup;
    }

    /**
     * Set the value of 个性化客户组内容
     *
     * @param mixed $discountUserGroup
     */
    public function setDiscountUserGroup($discountUserGroup) : void
    {
        $this->discountUserGroup = $discountUserGroup;
    }

    /**
     * Get the value of 商品类型，allGoods 所有商品，goodsClass
     * 商品分类，goodsBrand 商品品牌
     *
     * @return mixed
     */
    public function getDiscountGoodsType()
    {
        return $this->discountGoodsType;
    }

    /**
     * Set the value of 商品类型，allGoods 所有商品，goodsClass
     * 商品分类，goodsBrand 商品品牌
     *
     * @param mixed $discountGoodsType
     */
    public function setDiscountGoodsType($discountGoodsType) : void
    {
        $this->discountGoodsType = $discountGoodsType;
    }

    /**
     * Get the value of 商品类型的内容，如
     * 商品分类、商品品牌、个别商品
     *
     * @return mixed
     */
    public function getDiscountGoodsBody()
    {
        return $this->discountGoodsBody;
    }

    /**
     * Set the value of 商品类型的内容，如
     * 商品分类、商品品牌、个别商品
     *
     * @param mixed $discountGoodsBody
     */
    public function setDiscountGoodsBody($discountGoodsBody) : void
    {
        $this->discountGoodsBody = $discountGoodsBody;
    }


}

