<?php
/**
 * 珑大极简商城
 * 
 *  ==========================================================================
 *  @link      https://shop.loongdom.cn/
 *  @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 *  @license   https://shop.loongdom.cn/license.html License
 *  ==========================================================================
 * 
 * @author    静静的风
 */


namespace Sales\Entity;

use Admin\Entity\BaseEntity as BaseEntity;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\ORM\Mapping as ORM;

/**
 * 订单表
 *
 * @ORM\Entity(repositoryClass="Sales\Repository\OrderRepository")
 * @ORM\Table(name="loongdom_order")
 */
class Order extends BaseEntity
{

    /**
     * 自增id
     *
     * @ORM\Id()
     * @ORM\Column(name="order_id", type="integer", length=11)
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $orderId;

    /**
     * 订单编号
     *
     * @ORM\Column(name="order_sn", type="string", length=50)
     */
    private $orderSn;

    /**
     * 外部支付商户订单号
     *
     * @ORM\Column(name="out_trade_no", type="string", length=50)
     */
    private $outTradeNo;

    /**
     * 订单金额
     *
     * @ORM\Column(name="order_amount", type="decimal", scale=2)
     */
    private $orderAmount;

    /**
     * 商品总金额
     *
     * @ORM\Column(name="goods_amount", type="decimal", scale=2)
     */
    private $goodsAmount;

    /**
     * 订单状态
     *
     * @ORM\Column(name="order_status", type="integer", length=2)
     */
    private $orderStatus = 10;

    /**
     * 支付类型，在线支付 OnlinePay、货到付款 CashOnDelivery
     *
     * @ORM\Column(name="payment_type", type="string", length=30)
     */
    private $paymentType;

    /**
     * 支付代码
     *
     * @ORM\Column(name="payment_code", type="string", length=30)
     */
    private $paymentCode;

    /**
     * 支付名称
     *
     * @ORM\Column(name="payment_name", type="string", length=100)
     */
    private $paymentName;

    /**
     * 支付凭证，银行转账时使用
     *
     * @ORM\Column(name="payment_certification", type="string", length=500)
     */
    private $paymentCertification;

    /**
     * 支付完成时间
     *
     * @ORM\Column(name="payment_finish_time", type="integer", length=10)
     */
    private $paymentFinishTime;

    /**
     * 发货类型，快递配送 delivery 、到店自提 selfFetch、autoDelivery
     * 自动发货
     *
     * @ORM\Column(name="delivery_type", type="string", length=30)
     */
    private $deliveryType = 'delivery';

    /**
     * 订单配送方式，默认为0，只有在快递配送时启用。1
     * 整个订单统一配送，2 订单商品单独配送
     *
     * @ORM\Column(name="delivery_mode", type="integer", length=1)
     */
    private $deliveryMode = 0;

    /**
     * 快递id
     *
     * @ORM\Column(name="delivery_id", type="integer", length=11)
     */
    private $deliveryId;

    /**
     * 快递名称
     *
     * @ORM\Column(name="delivery_name", type="string", length=200)
     */
    private $deliveryName;

    /**
     * 快递单号
     *
     * @ORM\Column(name="express_number", type="string", length=50)
     */
    private $expressNumber;

    /**
     * 运费
     *
     * @ORM\Column(name="shipping_fee", type="decimal", scale=2)
     */
    private $shippingFee;

    /**
     * 发货时间
     *
     * @ORM\Column(name="express_time", type="integer", length=10)
     */
    private $expressTime;

    /**
     * 订单重量，默认为0
     *
     * @ORM\Column(name="order_weight_amount", type="integer", length=11)
     */
    private $orderWeightAmount;

    /**
     * 退货类型，默认为0无退货 退货1 退款2 退款退货3
     *
     * @ORM\Column(name="order_return_type", type="integer", length=1)
     */
    private $orderReturnType;

    /**
     * 订单留言
     *
     * @ORM\Column(name="order_message", type="string", length=500)
     */
    private $orderMessage;

    /**
     * 会员id
     *
     * @ORM\Column(name="user_id", type="integer", length=11)
     */
    private $userId;

    /**
     * 会员名称
     *
     * @ORM\Column(name="user_name", type="string", length=100)
     */
    private $userName;

    /**
     * 订单添加时间
     *
     * @ORM\Column(name="order_add_time", type="integer", length=10)
     */
    private $orderAddTime;

    /**
     * 订单完成时间（收货）
     *
     * @ORM\Column(name="order_finish_time", type="integer", length=10)
     */
    private $orderFinishTime;

    /**
     * 备注信息
     *
     * @ORM\Column(name="order_notes", type="string", length=500)
     */
    private $orderNotes;

    /**
     * @ORM\OneToMany(targetEntity="Sales\Entity\OrderGoods", mappedBy="order")
     * @ORM\JoinColumn(name="order_id", referencedColumnName="order_id")
     */
    protected $orderGoods;

    public function __construct()
    {
        $this->orderGoods = new ArrayCollection();
    }

    /**
     * @return ArrayCollection
     */
    public function getOrderGoods()
    {
        return $this->orderGoods;
    }

    /**
     * @param $orderGoods
     */
    public function addOrderGoods($orderGoods)
    {
        $this->orderGoods[] = $orderGoods;
    }

    /**
     * Get the value of 自增id
     *
     * @return mixed
     */
    public function getOrderId()
    {
        return $this->orderId;
    }

    /**
     * Set the value of 自增id
     *
     * @param mixed $orderId
     */
    public function setOrderId($orderId) : void
    {
        $this->orderId = $orderId;
    }

    /**
     * Get the value of 订单编号
     *
     * @return mixed
     */
    public function getOrderSn()
    {
        return $this->orderSn;
    }

    /**
     * Set the value of 订单编号
     *
     * @param mixed $orderSn
     */
    public function setOrderSn($orderSn) : void
    {
        $this->orderSn = $orderSn;
    }

    /**
     * Get the value of 外部支付商户订单号
     *
     * @return mixed
     */
    public function getOutTradeNo()
    {
        return $this->outTradeNo;
    }

    /**
     * Set the value of 外部支付商户订单号
     *
     * @param mixed $outTradeNo
     */
    public function setOutTradeNo($outTradeNo) : void
    {
        $this->outTradeNo = $outTradeNo;
    }

    /**
     * Get the value of 订单金额
     *
     * @return mixed
     */
    public function getOrderAmount()
    {
        return $this->orderAmount;
    }

    /**
     * Set the value of 订单金额
     *
     * @param mixed $orderAmount
     */
    public function setOrderAmount($orderAmount) : void
    {
        $this->orderAmount = $orderAmount;
    }

    /**
     * Get the value of 商品总金额
     *
     * @return mixed
     */
    public function getGoodsAmount()
    {
        return $this->goodsAmount;
    }

    /**
     * Set the value of 商品总金额
     *
     * @param mixed $goodsAmount
     */
    public function setGoodsAmount($goodsAmount) : void
    {
        $this->goodsAmount = $goodsAmount;
    }

    /**
     * Get the value of 订单状态
     *
     * @return mixed
     */
    public function getOrderStatus()
    {
        return $this->orderStatus;
    }

    /**
     * Set the value of 订单状态
     *
     * @param mixed $orderStatus
     */
    public function setOrderStatus($orderStatus) : void
    {
        $this->orderStatus = $orderStatus;
    }

    /**
     * Get the value of 支付类型，在线支付 OnlinePay、货到付款
     * CashOnDelivery
     *
     * @return mixed
     */
    public function getPaymentType()
    {
        return $this->paymentType;
    }

    /**
     * Set the value of 支付类型，在线支付 OnlinePay、货到付款
     * CashOnDelivery
     *
     * @param mixed $paymentType
     */
    public function setPaymentType($paymentType) : void
    {
        $this->paymentType = $paymentType;
    }

    /**
     * Get the value of 支付代码
     *
     * @return mixed
     */
    public function getPaymentCode()
    {
        return $this->paymentCode;
    }

    /**
     * Set the value of 支付代码
     *
     * @param mixed $paymentCode
     */
    public function setPaymentCode($paymentCode) : void
    {
        $this->paymentCode = $paymentCode;
    }

    /**
     * Get the value of 支付名称
     *
     * @return mixed
     */
    public function getPaymentName()
    {
        return $this->paymentName;
    }

    /**
     * Set the value of 支付名称
     *
     * @param mixed $paymentName
     */
    public function setPaymentName($paymentName) : void
    {
        $this->paymentName = $paymentName;
    }

    /**
     * Get the value of 支付凭证，银行转账时使用
     *
     * @return mixed
     */
    public function getPaymentCertification()
    {
        return $this->paymentCertification;
    }

    /**
     * Set the value of 支付凭证，银行转账时使用
     *
     * @param mixed $paymentCertification
     */
    public function setPaymentCertification($paymentCertification) : void
    {
        $this->paymentCertification = $paymentCertification;
    }

    /**
     * Get the value of 支付完成时间
     *
     * @return mixed
     */
    public function getPaymentFinishTime()
    {
        return $this->paymentFinishTime;
    }

    /**
     * Set the value of 支付完成时间
     *
     * @param mixed $paymentFinishTime
     */
    public function setPaymentFinishTime($paymentFinishTime) : void
    {
        $this->paymentFinishTime = $paymentFinishTime;
    }

    /**
     * Get the value of 发货类型，快递配送 delivery 、到店自提
     * selfFetch、autoDelivery 自动发货
     *
     * @return mixed
     */
    public function getDeliveryType()
    {
        return $this->deliveryType;
    }

    /**
     * Set the value of 发货类型，快递配送 delivery 、到店自提
     * selfFetch、autoDelivery 自动发货
     *
     * @param mixed $deliveryType
     */
    public function setDeliveryType($deliveryType) : void
    {
        $this->deliveryType = $deliveryType;
    }

    /**
     * Get the value of
     * 订单配送方式，默认为0，只有在快递配送时启用。1
     * 整个订单统一配送，2 订单商品单独配送
     *
     * @return mixed
     */
    public function getDeliveryMode()
    {
        return $this->deliveryMode;
    }

    /**
     * Set the value of
     * 订单配送方式，默认为0，只有在快递配送时启用。1
     * 整个订单统一配送，2 订单商品单独配送
     *
     * @param mixed $deliveryMode
     */
    public function setDeliveryMode($deliveryMode) : void
    {
        $this->deliveryMode = $deliveryMode;
    }

    /**
     * Get the value of 快递id
     *
     * @return mixed
     */
    public function getDeliveryId()
    {
        return $this->deliveryId;
    }

    /**
     * Set the value of 快递id
     *
     * @param mixed $deliveryId
     */
    public function setDeliveryId($deliveryId) : void
    {
        $this->deliveryId = $deliveryId;
    }

    /**
     * Get the value of 快递名称
     *
     * @return mixed
     */
    public function getDeliveryName()
    {
        return $this->deliveryName;
    }

    /**
     * Set the value of 快递名称
     *
     * @param mixed $deliveryName
     */
    public function setDeliveryName($deliveryName) : void
    {
        $this->deliveryName = $deliveryName;
    }

    /**
     * Get the value of 快递单号
     *
     * @return mixed
     */
    public function getExpressNumber()
    {
        return $this->expressNumber;
    }

    /**
     * Set the value of 快递单号
     *
     * @param mixed $expressNumber
     */
    public function setExpressNumber($expressNumber) : void
    {
        $this->expressNumber = $expressNumber;
    }

    /**
     * Get the value of 运费
     *
     * @return mixed
     */
    public function getShippingFee()
    {
        return $this->shippingFee;
    }

    /**
     * Set the value of 运费
     *
     * @param mixed $shippingFee
     */
    public function setShippingFee($shippingFee) : void
    {
        $this->shippingFee = $shippingFee;
    }

    /**
     * Get the value of 发货时间
     *
     * @return mixed
     */
    public function getExpressTime()
    {
        return $this->expressTime;
    }

    /**
     * Set the value of 发货时间
     *
     * @param mixed $expressTime
     */
    public function setExpressTime($expressTime) : void
    {
        $this->expressTime = $expressTime;
    }

    /**
     * Get the value of 订单重量，默认为0
     *
     * @return mixed
     */
    public function getOrderWeightAmount()
    {
        return $this->orderWeightAmount;
    }

    /**
     * Set the value of 订单重量，默认为0
     *
     * @param mixed $orderWeightAmount
     */
    public function setOrderWeightAmount($orderWeightAmount) : void
    {
        $this->orderWeightAmount = $orderWeightAmount;
    }

    /**
     * Get the value of 退货类型，默认为0无退货 退货1 退款2
     * 退款退货3
     *
     * @return mixed
     */
    public function getOrderReturnType()
    {
        return $this->orderReturnType;
    }

    /**
     * Set the value of 退货类型，默认为0无退货 退货1 退款2
     * 退款退货3
     *
     * @param mixed $orderReturnType
     */
    public function setOrderReturnType($orderReturnType) : void
    {
        $this->orderReturnType = $orderReturnType;
    }

    /**
     * Get the value of 订单留言
     *
     * @return mixed
     */
    public function getOrderMessage()
    {
        return $this->orderMessage;
    }

    /**
     * Set the value of 订单留言
     *
     * @param mixed $orderMessage
     */
    public function setOrderMessage($orderMessage) : void
    {
        $this->orderMessage = $orderMessage;
    }

    /**
     * Get the value of 会员id
     *
     * @return mixed
     */
    public function getUserId()
    {
        return $this->userId;
    }

    /**
     * Set the value of 会员id
     *
     * @param mixed $userId
     */
    public function setUserId($userId) : void
    {
        $this->userId = $userId;
    }

    /**
     * Get the value of 会员名称
     *
     * @return mixed
     */
    public function getUserName()
    {
        return $this->userName;
    }

    /**
     * Set the value of 会员名称
     *
     * @param mixed $userName
     */
    public function setUserName($userName) : void
    {
        $this->userName = $userName;
    }

    /**
     * Get the value of 订单添加时间
     *
     * @return mixed
     */
    public function getOrderAddTime()
    {
        return $this->orderAddTime;
    }

    /**
     * Set the value of 订单添加时间
     *
     * @param mixed $orderAddTime
     */
    public function setOrderAddTime($orderAddTime) : void
    {
        $this->orderAddTime = $orderAddTime;
    }

    /**
     * Get the value of 订单完成时间（收货）
     *
     * @return mixed
     */
    public function getOrderFinishTime()
    {
        return $this->orderFinishTime;
    }

    /**
     * Set the value of 订单完成时间（收货）
     *
     * @param mixed $orderFinishTime
     */
    public function setOrderFinishTime($orderFinishTime) : void
    {
        $this->orderFinishTime = $orderFinishTime;
    }

    /**
     * Get the value of 备注信息
     *
     * @return mixed
     */
    public function getOrderNotes()
    {
        return $this->orderNotes;
    }

    /**
     * Set the value of 备注信息
     *
     * @param mixed $orderNotes
     */
    public function setOrderNotes($orderNotes) : void
    {
        $this->orderNotes = $orderNotes;
    }


}

