<?php
/**
 * 珑大极简商城
 * 
 *  ==========================================================================
 *  @link      https://shop.loongdom.cn/
 *  @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 *  @license   https://shop.loongdom.cn/license.html License
 *  ==========================================================================
 * 
 * @author    静静的风
 */


namespace Sales\Entity;

use Admin\Entity\BaseEntity as BaseEntity;
use Doctrine\ORM\Mapping as ORM;

/**
 * 订单优惠记录信息
 *
 * @ORM\Entity(repositoryClass="Sales\Repository\OrderDiscountRecordRepository")
 * @ORM\Table(name="loongdom_order_discount_record")
 */
class OrderDiscountRecord extends BaseEntity
{

    /**
     * 自增id
     *
     * @ORM\Id()
     * @ORM\Column(name="record_id", type="integer", length=11)
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $recordId;

    /**
     * 优惠金额
     *
     * @ORM\Column(name="discount_cost", type="decimal", scale=2)
     */
    private $discountCost;

    /**
     * 优惠类型，如 discount 代表优惠促销规则，integral
     * 消费积分，couponCode 优惠码
     *
     * @ORM\Column(name="discount_type", type="string", length=30)
     */
    private $discountType;

    /**
     * 优惠描述，非规则标题和内容
     *
     * @ORM\Column(name="discount_info", type="string", length=200)
     */
    private $discountInfo;

    /**
     * 订单id
     *
     * @ORM\Column(name="order_id", type="integer", length=11)
     */
    private $orderId;

    /**
     * 会员id
     *
     * @ORM\Column(name="user_id", type="integer", length=11)
     */
    private $userId;

    /**
     * 对应各种优惠的规则id
     *
     * @ORM\Column(name="id", type="integer", length=11)
     */
    private $id;

    /**
     * Get the value of 自增id
     *
     * @return mixed
     */
    public function getRecordId()
    {
        return $this->recordId;
    }

    /**
     * Set the value of 自增id
     *
     * @param mixed $recordId
     */
    public function setRecordId($recordId) : void
    {
        $this->recordId = $recordId;
    }

    /**
     * Get the value of 优惠金额
     *
     * @return mixed
     */
    public function getDiscountCost()
    {
        return $this->discountCost;
    }

    /**
     * Set the value of 优惠金额
     *
     * @param mixed $discountCost
     */
    public function setDiscountCost($discountCost) : void
    {
        $this->discountCost = $discountCost;
    }

    /**
     * Get the value of 优惠类型，如 discount 代表优惠促销规则，integral
     * 消费积分，couponCode 优惠码
     *
     * @return mixed
     */
    public function getDiscountType()
    {
        return $this->discountType;
    }

    /**
     * Set the value of 优惠类型，如 discount 代表优惠促销规则，integral
     * 消费积分，couponCode 优惠码
     *
     * @param mixed $discountType
     */
    public function setDiscountType($discountType) : void
    {
        $this->discountType = $discountType;
    }

    /**
     * Get the value of 优惠描述，非规则标题和内容
     *
     * @return mixed
     */
    public function getDiscountInfo()
    {
        return $this->discountInfo;
    }

    /**
     * Set the value of 优惠描述，非规则标题和内容
     *
     * @param mixed $discountInfo
     */
    public function setDiscountInfo($discountInfo) : void
    {
        $this->discountInfo = $discountInfo;
    }

    /**
     * Get the value of 订单id
     *
     * @return mixed
     */
    public function getOrderId()
    {
        return $this->orderId;
    }

    /**
     * Set the value of 订单id
     *
     * @param mixed $orderId
     */
    public function setOrderId($orderId) : void
    {
        $this->orderId = $orderId;
    }

    /**
     * Get the value of 会员id
     *
     * @return mixed
     */
    public function getUserId()
    {
        return $this->userId;
    }

    /**
     * Set the value of 会员id
     *
     * @param mixed $userId
     */
    public function setUserId($userId) : void
    {
        $this->userId = $userId;
    }

    /**
     * Get the value of 对应各种优惠的规则id
     *
     * @return mixed
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set the value of 对应各种优惠的规则id
     *
     * @param mixed $id
     */
    public function setId($id) : void
    {
        $this->id = $id;
    }


}

