<?php
/**
 * 珑大极简商城
 * 
 *  ==========================================================================
 *  @link      https://shop.loongdom.cn/
 *  @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 *  @license   https://shop.loongdom.cn/license.html License
 *  ==========================================================================
 * 
 * @author    静静的风
 */


namespace Sales\Entity;

use Admin\Entity\BaseEntity as BaseEntity;
use Doctrine\ORM\Mapping as ORM;

/**
 * 订单商品表
 *
 * @ORM\Entity(repositoryClass="Sales\Repository\OrderGoodsRepository")
 * @ORM\Table(name="loongdom_order_goods")
 */
class OrderGoods extends BaseEntity
{

    /**
     * 自增id
     *
     * @ORM\Id()
     * @ORM\Column(name="order_goods_id", type="integer", length=11)
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $orderGoodsId;

    /**
     * 订单id
     *
     * @ORM\Column(name="order_id", type="integer", length=11)
     */
    private $orderId;

    /**
     * 商品id
     *
     * @ORM\Column(name="goods_id", type="integer", length=11)
     */
    private $goodsId;

    /**
     * 商品名称
     *
     * @ORM\Column(name="goods_name", type="string", length=200)
     */
    private $goodsName;

    /**
     * 商品货号
     *
     * @ORM\Column(name="goods_item", type="string", length=50)
     */
    private $goodsItem;

    /**
     * 订单商品价格
     *
     * @ORM\Column(name="goods_price", type="decimal", scale=2)
     */
    private $goodsPrice;

    /**
     * 商品图片，如果是网络图片直接存储地址，如不是则将图片保存到对应目录
     *
     * @ORM\Column(name="goods_image", type="string", length=300)
     */
    private $goodsImage;

    /**
     * 规格商品，规格信息
     *
     * @ORM\Column(name="in_spec_name", type="string", length=100)
     */
    private $inSpecName;

    /**
     * 规格商品id
     *
     * @ORM\Column(name="in_spec_goods_id", type="integer", length=11)
     */
    private $inSpecGoodsId;

    /**
     * 商品类型，1 实物，2 虚拟商品
     *
     * @ORM\Column(name="goods_type", type="integer", length=1)
     */
    private $goodsType;

    /**
     * 商品购买数量
     *
     * @ORM\Column(name="buy_num", type="decimal", scale=2)
     */
    private $buyNum;

    /**
     * 商品金额
     *
     * @ORM\Column(name="goods_amount", type="decimal", scale=2)
     */
    private $goodsAmount;

    /**
     * 商品重量
     *
     * @ORM\Column(name="goods_weight_amount", type="integer", length=11)
     */
    private $goodsWeightAmount;

    /**
     * 商品状态（发送，或者退货时）50 已发货，-10退货
     *
     * @ORM\Column(name="goods_status", type="integer", length=2)
     */
    private $goodsStatus = 0;

    /**
     * 商品评价状态，0 未评价，1 已评价
     *
     * @ORM\Column(name="evaluation_status", type="integer", length=1)
     */
    private $evaluationStatus = 0;

    /**
     * 会员id
     *
     * @ORM\Column(name="user_id", type="integer", length=11)
     */
    private $userId;

    /**
     * @ORM\ManyToOne(targetEntity="Sales\Entity\Order", inversedBy="orderGoods")
     * @ORM\JoinColumn(name="order_id", referencedColumnName="order_id")
     */
    protected $order;

    /**
     * @return mixed
     */
    public function getOrder()
    {
        return $this->order;
    }

    /**
     * @param $order
     */
    public function setOrder($order)
    {
        $this->order = $order;
        $order->addOrderGoods($this);
    }

    /**
     * Get the value of 自增id
     *
     * @return mixed
     */
    public function getOrderGoodsId()
    {
        return $this->orderGoodsId;
    }

    /**
     * Set the value of 自增id
     *
     * @param mixed $orderGoodsId
     */
    public function setOrderGoodsId($orderGoodsId) : void
    {
        $this->orderGoodsId = $orderGoodsId;
    }

    /**
     * Get the value of 订单id
     *
     * @return mixed
     */
    public function getOrderId()
    {
        return $this->orderId;
    }

    /**
     * Set the value of 订单id
     *
     * @param mixed $orderId
     */
    public function setOrderId($orderId) : void
    {
        $this->orderId = $orderId;
    }

    /**
     * Get the value of 商品id
     *
     * @return mixed
     */
    public function getGoodsId()
    {
        return $this->goodsId;
    }

    /**
     * Set the value of 商品id
     *
     * @param mixed $goodsId
     */
    public function setGoodsId($goodsId) : void
    {
        $this->goodsId = $goodsId;
    }

    /**
     * Get the value of 商品名称
     *
     * @return mixed
     */
    public function getGoodsName()
    {
        return $this->goodsName;
    }

    /**
     * Set the value of 商品名称
     *
     * @param mixed $goodsName
     */
    public function setGoodsName($goodsName) : void
    {
        $this->goodsName = $goodsName;
    }

    /**
     * Get the value of 商品货号
     *
     * @return mixed
     */
    public function getGoodsItem()
    {
        return $this->goodsItem;
    }

    /**
     * Set the value of 商品货号
     *
     * @param mixed $goodsItem
     */
    public function setGoodsItem($goodsItem) : void
    {
        $this->goodsItem = $goodsItem;
    }

    /**
     * Get the value of 订单商品价格
     *
     * @return mixed
     */
    public function getGoodsPrice()
    {
        return $this->goodsPrice;
    }

    /**
     * Set the value of 订单商品价格
     *
     * @param mixed $goodsPrice
     */
    public function setGoodsPrice($goodsPrice) : void
    {
        $this->goodsPrice = $goodsPrice;
    }

    /**
     * Get the value of
     * 商品图片，如果是网络图片直接存储地址，如不是则将图片保存到对应目录
     *
     * @return mixed
     */
    public function getGoodsImage()
    {
        return $this->goodsImage;
    }

    /**
     * Set the value of
     * 商品图片，如果是网络图片直接存储地址，如不是则将图片保存到对应目录
     *
     * @param mixed $goodsImage
     */
    public function setGoodsImage($goodsImage) : void
    {
        $this->goodsImage = $goodsImage;
    }

    /**
     * Get the value of 规格商品，规格信息
     *
     * @return mixed
     */
    public function getInSpecName()
    {
        return $this->inSpecName;
    }

    /**
     * Set the value of 规格商品，规格信息
     *
     * @param mixed $inSpecName
     */
    public function setInSpecName($inSpecName) : void
    {
        $this->inSpecName = $inSpecName;
    }

    /**
     * Get the value of 规格商品id
     *
     * @return mixed
     */
    public function getInSpecGoodsId()
    {
        return $this->inSpecGoodsId;
    }

    /**
     * Set the value of 规格商品id
     *
     * @param mixed $inSpecGoodsId
     */
    public function setInSpecGoodsId($inSpecGoodsId) : void
    {
        $this->inSpecGoodsId = $inSpecGoodsId;
    }

    /**
     * Get the value of 商品类型，1 实物，2 虚拟商品
     *
     * @return mixed
     */
    public function getGoodsType()
    {
        return $this->goodsType;
    }

    /**
     * Set the value of 商品类型，1 实物，2 虚拟商品
     *
     * @param mixed $goodsType
     */
    public function setGoodsType($goodsType) : void
    {
        $this->goodsType = $goodsType;
    }

    /**
     * Get the value of 商品购买数量
     *
     * @return mixed
     */
    public function getBuyNum()
    {
        return $this->buyNum;
    }

    /**
     * Set the value of 商品购买数量
     *
     * @param mixed $buyNum
     */
    public function setBuyNum($buyNum) : void
    {
        $this->buyNum = $buyNum;
    }

    /**
     * Get the value of 商品金额
     *
     * @return mixed
     */
    public function getGoodsAmount()
    {
        return $this->goodsAmount;
    }

    /**
     * Set the value of 商品金额
     *
     * @param mixed $goodsAmount
     */
    public function setGoodsAmount($goodsAmount) : void
    {
        $this->goodsAmount = $goodsAmount;
    }

    /**
     * Get the value of 商品重量
     *
     * @return mixed
     */
    public function getGoodsWeightAmount()
    {
        return $this->goodsWeightAmount;
    }

    /**
     * Set the value of 商品重量
     *
     * @param mixed $goodsWeightAmount
     */
    public function setGoodsWeightAmount($goodsWeightAmount) : void
    {
        $this->goodsWeightAmount = $goodsWeightAmount;
    }

    /**
     * Get the value of 商品状态（发送，或者退货时）50
     * 已发货，-10退货
     *
     * @return mixed
     */
    public function getGoodsStatus()
    {
        return $this->goodsStatus;
    }

    /**
     * Set the value of 商品状态（发送，或者退货时）50
     * 已发货，-10退货
     *
     * @param mixed $goodsStatus
     */
    public function setGoodsStatus($goodsStatus) : void
    {
        $this->goodsStatus = $goodsStatus;
    }

    /**
     * Get the value of 商品评价状态，0 未评价，1 已评价
     *
     * @return mixed
     */
    public function getEvaluationStatus()
    {
        return $this->evaluationStatus;
    }

    /**
     * Set the value of 商品评价状态，0 未评价，1 已评价
     *
     * @param mixed $evaluationStatus
     */
    public function setEvaluationStatus($evaluationStatus) : void
    {
        $this->evaluationStatus = $evaluationStatus;
    }

    /**
     * Get the value of 会员id
     *
     * @return mixed
     */
    public function getUserId()
    {
        return $this->userId;
    }

    /**
     * Set the value of 会员id
     *
     * @param mixed $userId
     */
    public function setUserId($userId) : void
    {
        $this->userId = $userId;
    }


}

