<?php
/**
 * 珑大极简商城
 * 
 *  ==========================================================================
 *  @link      https://shop.loongdom.cn/
 *  @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 *  @license   https://shop.loongdom.cn/license.html License
 *  ==========================================================================
 * 
 * @author    静静的风
 */


namespace User\Entity;

use Admin\Data\Common;
use Admin\Entity\BaseEntity as BaseEntity;
use Doctrine\ORM\Mapping as ORM;

/**
 * 客户表
 *
 * @ORM\Entity(repositoryClass="User\Repository\UserRepository")
 * @ORM\Table(name="loongdom_user")
 */
class User extends BaseEntity
{

    /**
     * 自增id
     *
     * @ORM\Id()
     * @ORM\Column(name="user_id", type="integer", length=11)
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $userId;

    /**
     * 客户组id
     *
     * @ORM\Column(name="user_group_id", type="integer", length=11)
     */
    private $userGroupId;

    /**
     * 客户名称
     *
     * @ORM\Column(name="user_name", type="string", length=100)
     */
    private $userName;

    /**
     * 客户头像
     *
     * @ORM\Column(name="user_avatar", type="string", length=200)
     */
    private $userAvatar;

    /**
     * 客户登录密码
     *
     * @ORM\Column(name="user_password", type="string", length=72)
     */
    private $userPassword;

    /**
     * 客户邮箱
     *
     * @ORM\Column(name="user_email", type="string", length=50)
     */
    private $userEmail;

    /**
     * 客户性别，1 男，2 女，3 保密
     *
     * @ORM\Column(name="user_sex", type="integer", length=1)
     */
    private $userSex;

    /**
     * 电话号码
     *
     * @ORM\Column(name="user_phone", type="string", length=20)
     */
    private $userPhone;

    /**
     * 状态 1 开启，2 关闭，3 待审核
     *
     * @ORM\Column(name="user_status", type="integer", length=1)
     */
    private $userStatus;

    /**
     * 添加时间
     *
     * @ORM\Column(name="user_add_time", type="integer", length=10)
     */
    private $userAddTime;

    /**
     * 客户组
     * @ORM\OneToOne(targetEntity="User\Entity\UserGroup")
     * @ORM\JoinColumn(name="user_group_id", referencedColumnName="user_group_id")
     */
    private $oneUserGroup;

    /**
     * @return mixed
     */
    public function getOneUserGroup()
    {
        return $this->oneUserGroup;
    }

    /**
     * @param mixed $oneUserGroup
     */
    public function setOneUserGroup($oneUserGroup): void
    {
        $this->oneUserGroup = $oneUserGroup;
    }

    /**
     * Get the value of 自增id
     *
     * @return mixed
     */
    public function getUserId()
    {
        return $this->userId;
    }

    /**
     * Set the value of 自增id
     *
     * @param mixed $userId
     */
    public function setUserId($userId) : void
    {
        $this->userId = $userId;
    }

    /**
     * Get the value of 客户组id
     *
     * @return mixed
     */
    public function getUserGroupId()
    {
        return $this->userGroupId;
    }

    /**
     * Set the value of 客户组id
     *
     * @param mixed $userGroupId
     */
    public function setUserGroupId($userGroupId) : void
    {
        $this->userGroupId = $userGroupId;
    }

    /**
     * Get the value of 客户名称
     *
     * @return mixed
     */
    public function getUserName()
    {
        return $this->userName;
    }

    /**
     * Set the value of 客户名称
     *
     * @param mixed $userName
     */
    public function setUserName($userName) : void
    {
        $this->userName = $userName;
    }

    /**
     * Get the value of 客户头像
     *
     * @return mixed
     */
    public function getUserAvatar()
    {
        return $this->userAvatar;
    }

    /**
     * Set the value of 客户头像
     *
     * @param mixed $userAvatar
     */
    public function setUserAvatar($userAvatar) : void
    {
        $this->userAvatar = $userAvatar;
    }

    /**
     * Get the value of 客户登录密码
     *
     * @return mixed
     */
    public function getUserPassword()
    {
        return $this->userPassword;
    }

    /**
     * Set the value of 客户登录密码
     *
     * @param mixed $userPassword
     */
    public function setUserPassword($userPassword) : void
    {
        $this->userPassword = Common::createPassword($userPassword);
    }

    /**
     * Get the value of 客户邮箱
     *
     * @return mixed
     */
    public function getUserEmail()
    {
        return $this->userEmail;
    }

    /**
     * Set the value of 客户邮箱
     *
     * @param mixed $userEmail
     */
    public function setUserEmail($userEmail) : void
    {
        $this->userEmail = $userEmail;
    }

    /**
     * Get the value of 客户性别，1 男，2 女，3 保密
     *
     * @return mixed
     */
    public function getUserSex()
    {
        return $this->userSex;
    }

    /**
     * Set the value of 客户性别，1 男，2 女，3 保密
     *
     * @param mixed $userSex
     */
    public function setUserSex($userSex) : void
    {
        $this->userSex = $userSex;
    }

    /**
     * Get the value of 电话号码
     *
     * @return mixed
     */
    public function getUserPhone()
    {
        return $this->userPhone;
    }

    /**
     * Set the value of 电话号码
     *
     * @param mixed $userPhone
     */
    public function setUserPhone($userPhone) : void
    {
        $this->userPhone = $userPhone;
    }

    /**
     * Get the value of 状态 1 开启，2 关闭，3 待审核
     *
     * @return mixed
     */
    public function getUserStatus()
    {
        return $this->userStatus;
    }

    /**
     * Set the value of 状态 1 开启，2 关闭，3 待审核
     *
     * @param mixed $userStatus
     */
    public function setUserStatus($userStatus) : void
    {
        $this->userStatus = $userStatus;
    }

    /**
     * Get the value of 添加时间
     *
     * @return mixed
     */
    public function getUserAddTime()
    {
        return $this->userAddTime;
    }

    /**
     * Set the value of 添加时间
     *
     * @param mixed $userAddTime
     */
    public function setUserAddTime($userAddTime) : void
    {
        $this->userAddTime = $userAddTime;
    }


}

